@@ -262,7 +262,7 @@ class AriaService:
     @staticmethod
     def set_text(message, text, data=None):
         if isinstance(text, SymphonyMessageML):
-            message['payload']['message'] = text.__str__()
+            message['payload']['message'] = text.tostring()
         else:
             message['payload']['message'] = text
         if data is not None:
@@ -291,39 +291,46 @@ class SymphonyMessageML:
     def __init__(self):
         self._root = etree.Element('messageML')
 
+    def tostring(self):
+        return etree.tostring(self._root).decode('utf-8')
+
     def root(self):
         return self._root
 
-    @staticmethod
-    def bold(text=None):
-        _elem = etree.Element('b')
-        if text is not None:
-            _elem.text = text
-        return _elem\
+    def text(self, text):
+        self._root[len(self._root)-1].text = text
+        return self
 
-    @staticmethod
-    def tbreak(text=None):
-        _elem = etree.Element('br')
-        if text is not None:
-            _elem.text = text
-        return _elem
+    def tail(self, text):
+        self._root[len(self._root)-1].tail = text
+        return self
 
-    @staticmethod
-    def hrule(text=None):
-        _elem = etree.Element('hr')
+    def bold(self, text=None):
+        _elem = etree.SubElement(self._root, 'b')
         if text is not None:
             _elem.text = text
-        return _elem\
+        return self
 
-    @staticmethod
-    def italic(text=None):
-        _elem = etree.Element('i')
+    def tbreak(self, text=None):
+        _elem = etree.SubElement(self._root, 'br')
         if text is not None:
             _elem.text = text
-        return _elem
+        return self
+
+    def hrule(self, text=None):
+        _elem = etree.SubElement(self._root, 'hr')
+        if text is not None:
+            _elem.text = text
+        return self
+
+    def italic(self, text=None):
+        _elem = etree.SubElement(self._root, 'i')
+        if text is not None:
+            _elem.text = text
+        return self
 
     def __str__(self):
-        return etree.tostring(self._root).decode('utf-8')
+        return self.tostring()
 
 
 __all__ = ['AriaService', 'SymphonyMessageML', 'AriaError']
