@@ -41,15 +41,11 @@ class AriaBot:
         self._populate_entity_handlers()
         self.session = None
         self.aria = None
-        self._delta_token = None
-        if 'read_token_file' in self.env:
-            self.read_token_file = pathlib.Path(self.env['read_token_file'])
-            if not self.read_token_file.exists():
-                self.read_token_file.write_text('')
-        else:
-            self.read_token_file = pathlib.Path('read_token_file.dat')
+        self._delta_token = ''
+        self.read_token_file = pathlib.Path(self.env.get('read_token_file', 'read_token_file.dat'))
+        if not self.read_token_file.exists():
+            logging.warning('Token file {0} doesnt exist, creating new file'.format(self.read_token_file.name))
             self.read_token_file.write_text('')
-            logging.warning('read_token_file not set in config, creating new file {0}'.format(self.read_token_file.name))
 
     def _populate_commands(self):
         if 'commands' not in self.config:
